@@ -5,60 +5,60 @@ package DataFlow::Node;
 use strict;
 use warnings;
 
-our $VERSION = '0.91.06';    # VERSION
+our $VERSION = '0.91.07';    # VERSION
 
 use Moose;
 
 use Scalar::Util qw/blessed reftype/;
 use Queue::Base;
 
-has name => (
-    is  => 'ro',
-    isa => 'Str',
+has 'name' => (
+    'is'  => 'ro',
+    'isa' => 'Str',
 );
 
-has deref => (
-    is      => 'ro',
-    isa     => 'Bool',
-    lazy    => 1,
-    default => 0,
+has 'deref' => (
+    'is'      => 'ro',
+    'isa'     => 'Bool',
+    'lazy'    => 1,
+    'default' => 0,
 );
 
-has process_into => (
-    is      => 'ro',
-    isa     => 'Bool',
-    lazy    => 1,
-    default => 1,
+has 'process_into' => (
+    'is'      => 'ro',
+    'isa'     => 'Bool',
+    'lazy'    => 1,
+    'default' => 1,
 );
 
-has auto_process => (
-    is      => 'ro',
-    isa     => 'Bool',
-    lazy    => 1,
-    default => 1,
+has 'auto_process' => (
+    'is'      => 'ro',
+    'isa'     => 'Bool',
+    'lazy'    => 1,
+    'default' => 1,
 );
 
-has initial_data => (
-    is      => 'ro',
-    isa     => 'ArrayRef',
-    trigger => sub {
+has 'initial_data' => (
+    'is'      => 'ro',
+    'isa'     => 'ArrayRef',
+    'trigger' => sub {
         my ( $self, $new ) = @_;
         $self->input( @{$new} );
     },
 );
 
-has _dumper => (
-    is      => 'ro',
-    isa     => 'CodeRef',
-    lazy    => 1,
-    default => sub {
+has '_dumper' => (
+    'is'      => 'ro',
+    'isa'     => 'CodeRef',
+    'lazy'    => 1,
+    'default' => sub {
         use Data::Dumper;
         return sub {
             return Dumper(@_);
         };
     },
-    handles => {
-        prefix_dumper => sub {
+    'handles' => {
+        'prefix_dumper' => sub {
             my ( $self, $prefix, @args ) = @_;
             print STDERR $prefix;
             if (@args) {
@@ -68,46 +68,46 @@ has _dumper => (
                 print STDERR "\n";
             }
         },
-        raw_dumper => sub {
+        'raw_dumper' => sub {
             my $self = shift;
             print STDERR $self->_dumper->(@_);
         },
     },
 );
 
-has dump_input => (
-    is      => 'ro',
-    isa     => 'Bool',
-    lazy    => 1,
-    default => 0,
+has 'dump_input' => (
+    'is'      => 'ro',
+    'isa'     => 'Bool',
+    'lazy'    => 1,
+    'default' => 0,
 );
 
-has dump_output => (
-    is      => 'ro',
-    isa     => 'Bool',
-    lazy    => 1,
-    default => 0,
+has 'dump_output' => (
+    'is'      => 'ro',
+    'isa'     => 'Bool',
+    'lazy'    => 1,
+    'default' => 0,
 );
 
-has process_item => (
-    is       => 'ro',
-    isa      => 'CodeRef',
-    required => 1,
+has 'process_item' => (
+    'is'       => 'ro',
+    'isa'      => 'CodeRef',
+    'required' => 1,
 );
 
 ##############################################################################
 # node input queue
 
 has 'inputq' => (
-    is      => 'ro',
-    isa     => 'Queue::Base',
-    default => sub { Queue::Base->new },
-    handles => {
-        _add_input => 'add',
-        input      => sub { my $self = shift; return $self->_add_input(@_); },
-        _dequeue_input => sub { return shift->inputq->remove(1); },
-        clear_input    => 'clear',
-        has_input      => sub { return !shift->inputq->empty; },
+    'is'      => 'ro',
+    'isa'     => 'Queue::Base',
+    'default' => sub { Queue::Base->new },
+    'handles' => {
+        '_add_input' => 'add',
+        'input'      => sub { my $self = shift; return $self->_add_input(@_); },
+        '_dequeue_input' => sub { return shift->inputq->remove(1); },
+        'clear_input'    => 'clear',
+        'has_input'      => sub { return !shift->inputq->empty; },
     },
 );
 
@@ -132,17 +132,17 @@ sub process_input {
 # node output queue
 
 has 'outputq' => (
-    is      => 'ro',
-    isa     => 'Queue::Base',
-    default => sub { Queue::Base->new },
-    handles => {
-        _add_output     => 'add',
-        _dequeue_output => sub {
+    'is'      => 'ro',
+    'isa'     => 'Queue::Base',
+    'default' => sub { Queue::Base->new },
+    'handles' => {
+        '_add_output'     => 'add',
+        '_dequeue_output' => sub {
             my $self = shift;
             return
               wantarray ? $self->outputq->remove_all : $self->outputq->remove;
         },
-        has_output => sub {
+        'has_output' => sub {
             return 0 < shift->outputq->size;
         },
     },
@@ -193,20 +193,20 @@ sub process {
 # node error queue
 
 has '_errorq' => (
-    is      => 'ro',
-    isa     => 'Queue::Base',
-    lazy    => 1,
-    default => sub { Queue::Base->new },
-    handles => {
-        _enqueue_error  => 'add',
-        _is_error_empty => 'empty',
-        _dequeue_error  => sub {
+    'is'      => 'ro',
+    'isa'     => 'Queue::Base',
+    'lazy'    => 1,
+    'default' => sub { Queue::Base->new },
+    'handles' => {
+        '_enqueue_error'  => 'add',
+        '_is_error_empty' => 'empty',
+        '_dequeue_error'  => sub {
             my $self = shift;
             return
               wantarray ? $self->errorq->remove_all : $self->errorq->remove;
         },
-        flush_error => 'clear',
-        clear_error => 'clear',
+        'flush_error' => 'clear',
+        'clear_error' => 'clear',
     },
 );
 
@@ -253,10 +253,10 @@ sub _handle_list {
 #
 
 has '_handlers' => (
-    is      => 'ro',
-    isa     => 'HashRef[CodeRef]',
-    lazy    => 1,
-    default => sub {
+    'is'      => 'ro',
+    'isa'     => 'HashRef[CodeRef]',
+    'lazy'    => 1,
+    'default' => sub {
         my $me           = shift;
         my $type_handler = {
             'SVALUE' => \&_handle_svalue,
@@ -324,7 +324,7 @@ DataFlow::Node - A generic processing node in a data flow
 
 =head1 VERSION
 
-version 0.91.06
+version 0.91.07
 
 =head1 SYNOPSIS
 
@@ -589,34 +589,6 @@ L<Scalar::Util>
 
 L<Queue::Base>
 
-=head1 INCOMPATIBILITIES
-
-=for author to fill in:
-    A list of any modules that this module cannot be used in conjunction
-    with. This may be due to name conflicts in the interface, or
-    competition for system or program resources, or due to internal
-    limitations of Perl (for example, many modules that use source code
-    filters are mutually incompatible).
-
-None reported.
-
-=head1 BUGS AND LIMITATIONS
-
-=for author to fill in:
-    A list of known problems with the module, together with some
-    indication Whether they are likely to be fixed in an upcoming
-    release. Also a list of restrictions on the features the module
-    does provide: data types that cannot be handled, performance issues
-    and the circumstances in which they may arise, practical
-    limitations on the size of data sets, special cases that are not
-    (yet) handled, etc.
-
-No bugs have been reported.
-
-Please report any bugs or feature requests to
-C<bug-dataflow@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
-
 =head1 AUTHOR
 
 Alexei Znamensky <russoz@cpan.org>
@@ -628,6 +600,47 @@ This software is copyright (c) 2011 by Alexei Znamensky.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://github.com/russoz/DataFlow/issues>.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<http://search.cpan.org/dist/DataFlow/>.
+
+The development version lives at L<http://github.com/russoz/DataFlow>
+and may be cloned from L<git://github.com/russoz/DataFlow.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
 =cut
 
 __END__
