@@ -5,7 +5,7 @@ package DataFlow::Node::HTMLFilter;
 use strict;
 use warnings;
 
-our $VERSION = '0.91.06';    # VERSION
+our $VERSION = '0.91.07';    # VERSION
 
 use Moose;
 extends 'DataFlow::Node';
@@ -13,29 +13,29 @@ extends 'DataFlow::Node';
 use Moose::Util::TypeConstraints;
 use HTML::TreeBuilder::XPath;
 
-has search_xpath => (
-    is       => 'ro',
-    isa      => 'Str',
-    required => 1,
+has 'search_xpath' => (
+    'is'       => 'ro',
+    'isa'      => 'Str',
+    'required' => 1,
 );
 
-enum _result_type => [qw(NODE HTML VALUE)];
+enum '_result_type' => [qw(NODE HTML VALUE)];
 
-has result_type => (
-    is      => 'ro',
-    isa     => '_result_type',
-    default => 'HTML',
+has 'result_type' => (
+    'is'      => 'ro',
+    'isa'     => '_result_type',
+    'default' => 'HTML',
 );
 
-has ref_result => (
-    is      => 'ro',
-    isa     => 'Bool',
-    default => 0,
+has 'ref_result' => (
+    'is'      => 'ro',
+    'isa'     => 'Bool',
+    'default' => 0,
 );
 
 has '+process_item' => (
-    lazy    => 1,
-    default => sub {
+    'lazy'    => 1,
+    'default' => sub {
         my $self = shift;
 
         my $proc = sub {
@@ -76,7 +76,7 @@ DataFlow::Node::HTMLFilter - A HTML filtering node
 
 =head1 VERSION
 
-version 0.91.06
+version 0.91.07
 
 =head1 SYNOPSIS
 
@@ -113,10 +113,6 @@ This node type provides a filter for HTML content.
 Each item will be considered as a HTML content and will be filtered
 using L<HTML::TreeBuilder::XPath>.
 
-=head1 NAME
-
-DataFlow::Node::HTMLFilter - A filter node for HTML content.
-
 =head1 ATTRIBUTES
 
 =head2 search_xpath
@@ -173,16 +169,6 @@ L<HTML::TreeBuilder::XPath>
 
 L<HTML::Element>
 
-=head1 INCOMPATIBILITIES
-
-None reported.
-
-=head1 BUGS AND LIMITATIONS
-
-Please report any bugs or feature requests to
-C<bug-dataflow@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
-
 =head1 AUTHOR
 
 Alexei Znamensky <russoz@cpan.org>
@@ -194,6 +180,47 @@ This software is copyright (c) 2011 by Alexei Znamensky.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://github.com/russoz/DataFlow/issues>.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see L<http://search.cpan.org/dist/DataFlow/>.
+
+The development version lives at L<http://github.com/russoz/DataFlow>
+and may be cloned from L<git://github.com/russoz/DataFlow.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
+WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
+PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
+EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
+IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
+SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
+THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
+TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
+SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
+DAMAGES.
+
 =cut
 
 __END__
